@@ -102,7 +102,7 @@ class Posting_itemsManager(OperationsManager):
                 setAttr(child, 'status', task_opt_detail_status)
                 child = Operations.objects.create(**child)
 
-                if item.resource == None:
+                if item.resource is None:
                     OperationsManager.set_location(operation_id=child.id, location_id=item.location_id)
                 else:
                     Operation_resources.objects.create(operation=child, resource=item.resource)
