@@ -78,7 +78,7 @@ class Tmp_bufferManager(CommonManagetWithLookUpFieldsManager):
         data = request.get_data()
         _data = data.copy()
 
-        if data.get('item_id') == None:
+        if data.get('item_id') is None:
             raise Exception('Не выбрана товарная позиция.')
 
         delAttr(_data, 'dataSource')
