@@ -79,7 +79,7 @@ class AttrManager(BaseRefManager):
         settings.LOCKS.acquire(key)
 
         attr_codes = attr_codes.split('.')
-        attr_names = attr_names.split('.') if attr_names != None else []
+        attr_names = attr_names.split('.') if attr_names is not None else []
         attr_type = None
         parent_attr_type = None
         i = 0
@@ -98,7 +98,7 @@ class AttrManager(BaseRefManager):
 
             parent_attr_type = attr_type
 
-        if attr_type == None:
+        if attr_type is None:
             settings.LOCKS.release(key)
             raise Exception(f'Failed to create type with code {attr_codes}.')
 
