@@ -172,13 +172,25 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
     def find_item1_contains(**kwargs):
         STMP_1 = kwargs.get('STMP_1')
         STMP_2 = kwargs.get('STMP_2')
+        deleted_at = kwargs.get('deleted_at')
 
-        if STMP_2 is None:
-            item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_1))
-        elif STMP_1 is None:
-            item_query = Item.objects.filter(STMP_2__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_2))
+        if STMP_2 is None and STMP_1 is not None:
+            if deleted_at is None:
+                item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_1), deleted_at=None)
+            else:
+                item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_1))
+        elif STMP_1 is None and STMP_2 is not None:
+            if deleted_at is None:
+                item_query = Item.objects.filter(STMP_2__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_2), deleted_at=None)
+            else:
+                item_query = Item.objects.filter(STMP_2__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_2))
+        elif STMP_1 is not None and STMP_2 is not None:
+            if deleted_at is None:
+                item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_1), STMP_2__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_2), deleted_at=None)
+            else:
+                item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_1), STMP_2__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_2))
         else:
-            item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_1), STMP_2__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_2))
+            return []
 
         return [item for item in item_query]
 
@@ -750,6 +762,15 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
             if isinstance(records, list):
                 return ItemManager._getQtyChilds(records=records)
 
+    def getGrouping(self, request):
+
+        request = DSRequest(request=request)
+        data = request.get_data()
+        if isinstance(data, dict):
+            records = data.get('records')
+            if isinstance(records, list):
+                return ItemManager._getQtyChilds(records=records)
+
 
 class Item_add:
     @staticmethod
