@@ -42,7 +42,6 @@ class LocationsManager(CommonManagetWithLookUpFieldsManager):
             'deliting': record.deliting,
             'isWorkshop': record.props.isWorkshop,
             'props': record.props,
-            'level_grouping': record.level_grouping,
         }
         return DelProps(res)
 
@@ -54,7 +53,6 @@ class Locations(BaseRefHierarcy):
     code = CodeStrictField(unique=True)
     calendar = ForeignKeyProtect(Calendars, null=True, blank=True)
     color = CodeField()
-    level_grouping = SmallIntegerField(null=True, blank=True)
     props = LocationsManager.props()
 
     objects = LocationsManager()
