@@ -1,3 +1,4 @@
+from isc_common.http.DSRequest import DSRequest
 from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException, JsonWSResponseWithException
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.http.response import JsonResponse
@@ -8,7 +9,7 @@ from kaf_pas.planing.models.operation_item_view import Operation_item_viewManage
 
 @JsonResponseWithException()
 def Item_flat_view_Fetch(request):
-    # _request = DSRequest(request=request)
+    _request = DSRequest(request=request)
 
     return JsonResponse(
         DSResponse(
