@@ -73,6 +73,7 @@ def Item_view_Variants_Fetch(request):
     from isc_common.isc.data_binding.criteria_stack import CriteriaStack
 
     _request = DSRequest(request=request)
+    alive_only = _request.json.get('alive_only')
 
     criteria = _request.get_criteria()
 
@@ -81,6 +82,10 @@ def Item_view_Variants_Fetch(request):
 
     res = CriteriaStack(criteria)
     item = dict()
+    if alive_only == True:
+        setAttr(item, 'deleted_at', None)
+    else:
+        setAttr(item, 'deleted_at', False)
 
     def get_item(criterion):
         if isinstance(criterion, AdvancedCriteria):
@@ -119,7 +124,7 @@ def Item_view_Variants_Fetch(request):
     else:
         items = ItemManager.find_item1_contains(**item)
         item_refs_Stack = Item_refs_Stack()
-        item_refs = [row[0] for row in item_refs_Stack.add_childs(id=[a.id for a in items])]
+        item_refs = [row[0] for row in item_refs_Stack.add_childs(id=[a.id for a in items], alive_only=alive_only)]
 
     return JsonResponse(
         DSResponse(
@@ -133,6 +138,7 @@ def Item_view_Variants_Fetch(request):
             ),
             status=RPCResponseConstant.statusSuccess).response)
 
+
 @JsonResponseWithException()
 def Item_view_Teach_Fetch(request):
     from kaf_pas.production.models.ready_2_launch_ext import Item_refs_Stack
@@ -156,6 +162,7 @@ def Item_view_Teach_Fetch(request):
             ),
             status=RPCResponseConstant.statusSuccess).response)
 
+
 @JsonResponseWithException()
 def Item_view_4_idFetch(request):
     # _request = DSRequest(request=request)
