@@ -23,7 +23,16 @@ class GridCoonstant:
     refresh_item_view_grid = "refresh_item_view_grid"
     refresh_item_view_grid_row = "refresh_item_view_grid_row"
 
+    refresh_item_variant_view_grid = "refresh_item_variant_view_grid"
+    refresh_item_variant_view_grid_row = "refresh_item_variant_view_grid_row"
+
     tmp_operation_value_view_grid = "tmp_operation_value_view_grid"
     tmp_operation_value_view_grid_row = "tmp_operation_value_view_grid_row"
 
     lock_insert_update_delete_function_of_table = "lock_insert_update_delete_function_of_table"
+
+    refresh_uploades_documents_grid = "refresh_uploades_documents_grid"
+    refresh_uploades_documents_grid_row = "refresh_uploades_documents_grid_row"
+
+    refresh_upload_logs_grid = "refresh_upload_logs_grid";
+    refresh_upload_logs_grid_row = "refresh_upload_logs_grid_row";
