@@ -25,7 +25,7 @@ class Document_attributesQuerySet(CommonManagetWithLookUpFieldsQuerySet):
         attr_type = kwargs.get('attr_type')
         if isinstance(attr_type, Attr_type):
             value_str = kwargs.get('value_str')
-            if value_str != None:
+            if value_str is not None:
                 setAttr(kwargs, 'value_str', value_str.strip())
             return super().create(**kwargs)
 
@@ -44,12 +44,12 @@ class Document_attributesQuerySet(CommonManagetWithLookUpFieldsQuerySet):
         attr_type = kwargs.get('attr_type')
         if isinstance(attr_type, Attr_type):
             value_str = kwargs.get('value_str')
-            if value_str != None:
+            if value_str is not None:
                 setAttr(kwargs, 'value_str', value_str.strip())
             return super().get_or_create(defaults, **kwargs)
 
         value_str = kwargs.get('value_str')
-        if value_str != None:
+        if value_str is not None:
             value_str = value_str.strip()
 
         if not kwargs.get('attr_type_id') and kwargs.get('attr_type__code'):
@@ -159,7 +159,7 @@ class Document_attributesManager(CommonManagetWithLookUpFieldsManager):
         with transaction.atomic():
             document_attributes = Document_attributes.objects.get(id=document_attribute.get('id'))
             document_attributes.value_str = document_attribute.get('value_str').strip()
-            if document_attribute.get('value_int') != None:
+            if document_attribute.get('value_int') is not None:
                 document_attributes.value_int = document_attribute.get('value_int')
             else:
                 document_attributes.value_int = StrToNumber(document_attribute.get('value_str').strip())
@@ -176,9 +176,9 @@ class Document_attributesManager(CommonManagetWithLookUpFieldsManager):
         request = DSRequest(request=request)
         data = request.get_data()
 
-        if data.get('value_int') != None and data.get('value_str') == None:
+        if data.get('value_int') is not None and data.get('value_str') is None:
             setAttr(data, 'value_str', str(data.get('value_int')))
-        elif data.get('value_int') == None and data.get('value_str') != None:
+        elif data.get('value_int') is None and data.get('value_str') is not None:
             setAttr(data, 'value_int', StrToNumber(data.get('value_str')))
 
         _data = data.copy()
@@ -188,7 +188,7 @@ class Document_attributesManager(CommonManagetWithLookUpFieldsManager):
         if props > -1:
             setAttr(_data, 'props', props)
         res = super().create(**_data)
-        if data.get('value_int') != None:
+        if data.get('value_int') is not None:
             res.value_int = _data.get('value_int')
             res.save()
 
