@@ -61,16 +61,46 @@ class Documents_thumbManager(CryptoManager):
 
     @staticmethod
     def getRecord(record):
-        res = {
-            "id": record.id,
-            "path": record.file_name,
-            "lastmodified": record.lastmodified,
-            "editing": record.editing,
-            "deliting": record.deliting,
-            "file_document_thumb_url": f'/logic/DocumentsThumb/Download/{record.id}/',
+        from isc_common import delete_drive_leter
+        if settings.ENABLE_FILE_VIEW:
+
+            file_document_names = os.path.split(record.document.file_document) if record.document is not None else None
+            if file_document_names is None:
+                file_document_names = os.path.split(record.lotsman_document.document.file_document) if record.lotsman_document is not None and record.lotsman_document.document else None
+
+            file_document_name = file_document_names[len(file_document_names) - 1]
+            file_names = delete_drive_leter(record.path).split('\\')
+            file_name = file_names[len(file_names) - 1]
+
+            file_document_path = record.document.file_document if record.document is not None else None
+            if file_document_path is None:
+                file_document_path = record.lotsman_document.document.file_document if record.lotsman_document is not None and record.lotsman_document.document is not None else None
+
+            res = {
+                'attfile_path': record.attfile.path,
+                'deliting': record.deliting,
+                'editing': record.editing,
+                'file_document_name': file_document_name,
+                'file_document_path': file_document_path,
+                'file_document_thumb_url': f'/logic/DocumentsThumb/Download/{record.id}/',
+                'file_name': file_name,
+                'file_path': delete_drive_leter(record.path),
+                'id': record.id,
+                'lastmodified': record.lastmodified,
+                'path': record.file_name,
+            }
+            return res
+        else:
+            res = {
+                'deliting': record.deliting,
+                'editing': record.editing,
+                'file_document_thumb_url': f'/logic/DocumentsThumb/Download/{record.id}/',
+                'id': record.id,
+                'lastmodified': record.lastmodified,
+                'path': record.file_name,
+            }
+            return res
 
-        }
-        return res
 
     def deleteFromRequest(self, request, removed=None, ):
         res = 0
