@@ -25,7 +25,7 @@ class Lotsman_documents_hierarcyManagerExt:
         from kaf_pas.kd.models.lotsman_documents_hierarcy import Lotsman_documents_hierarcy
         from kaf_pas.kd.models.lotsman_documents_hierarcy_view import Lotsman_documents_hierarcy_view
         from kaf_pas.system.models.contants import Contants
-        from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refsManager
+        # from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refsManager
 
         items_pairs = Stack()
 
@@ -43,7 +43,7 @@ class Lotsman_documents_hierarcyManagerExt:
             )
 
             item_refs, _ = Item_refs.objects.get_or_create(child=top_item)
-            if item_refs.parent != None:
+            if item_refs.parent is not None:
                 item_refs.delete()
                 item_refs, _ = Item_refs.objects.get_or_create(child=top_item)
 
@@ -60,16 +60,16 @@ class Lotsman_documents_hierarcyManagerExt:
                     value=top_item.id)
             )
 
-            if lotsman_documents_hierarcy_view_record.parent_id != None:
+            if lotsman_documents_hierarcy_view_record.parent_id is not None:
                 while True:
                     try:
                         item = Item.objects.get(lotsman_document_id=lotsman_documents_hierarcy_view_record.id, )
                         top_item = item
                         break
                     except Item.DoesNotExist:
-                        if lotsman_documents_hierarcy_view_record.parent_id != None:
+                        if lotsman_documents_hierarcy_view_record.parent_id is not None:
                             lotsman_documents_hierarcy_view_record = Lotsman_documents_hierarcy_view.objects.get(id=lotsman_documents_hierarcy_view_record.parent_id)
-                            if lotsman_documents_hierarcy_view_record.parent_id == None:
+                            if lotsman_documents_hierarcy_view_record.parent_id is None:
                                 top_item.lotsman_document_id = lotsman_documents_hierarcy_view_record.id
                                 if lotsman_documents_hierarcy_view_record._Version:
                                     top_item.version = lotsman_documents_hierarcy_view_record._Version.value_int,
@@ -102,7 +102,7 @@ class Lotsman_documents_hierarcyManagerExt:
 
                            select * from r where {props_str} order by level'''
 
-            mat_view_name = create_tmp_mat_view(sql_str=sql_str, indexes=['attr_name', 'parent_id'])
+            mat_view_name = create_tmp_mat_view(sql_str=sql_str, indexes=['attr_name', 'parent_id'],check_exists=True)
 
             with connection.cursor() as cursor:
                 cursor.execute(f'select count(*) from {mat_view_name} where props=1')
@@ -122,7 +122,7 @@ class Lotsman_documents_hierarcyManagerExt:
                 ) as progress:
                     with transaction.atomic():
 
-                        Tmp_Item_refsManager.create()
+                        # Tmp_Item_refsManager.create()
                         for lotsman_documents_hierarcy in Lotsman_documents_hierarcy_view.objects.raw(f'''select * from {mat_view_name}  where props=1 order by level'''):
                             if lotsman_documents_hierarcy.attr_name not in ['Материал']:
 
@@ -131,7 +131,7 @@ class Lotsman_documents_hierarcyManagerExt:
                                     items_pairs=items_pairs,
                                 )
 
-                                if lotsman_documents_hierarcy.parent_id != None:
+                                if lotsman_documents_hierarcy.parent_id is not None:
                                     try:
                                         _lotsman_documents_hierarcy = Lotsman_documents_hierarcy_view.objects.get(id=lotsman_documents_hierarcy.parent_id)
                                     except Lotsman_documents_hierarcy_view.DoesNotExist as ex:
@@ -313,7 +313,7 @@ class Lotsman_documents_hierarcyManagerExt:
 
                 if lotsman_documents_hierarcy.attr_name != 'Материал':
 
-                    if lotsman_documents_hierarcy.section == None:
+                    if lotsman_documents_hierarcy.section is None:
                         if lotsman_documents_hierarcy.attr_name in ['Чертеж', 'Спецификация']:
                             lotsman_documents_hierarcy.section = 'Документация'
                         elif lotsman_documents_hierarcy.attr_name in ['Сборочная единица']:
@@ -321,7 +321,7 @@ class Lotsman_documents_hierarcyManagerExt:
                         elif lotsman_documents_hierarcy.attr_name in ['Деталь']:
                             lotsman_documents_hierarcy.section = 'Детали'
 
-                    if lotsman_documents_hierarcy.section == None:
+                    if lotsman_documents_hierarcy.section is None:
                         lotsman_documents_hierarcy.section = lotsman_documents_hierarcy.attr_name
 
                     Документ_на_материал = None
