@@ -143,7 +143,6 @@ class PathesManager(CommonManagetWithLookUpFieldsManager):
     def deleteFromRequest(self, request, removed=None, ):
         from django.db import transaction
         from isc_common.auth.models.user import User
-        from isc_common.models.deleted_progresses import Deleted_progresses
         from kaf_pas.kd.models.documents import DocumentManager
         from kaf_pas.kd.models.documents import Documents
         from kaf_pas.kd.models.uploades import Uploades
@@ -168,7 +167,7 @@ class PathesManager(CommonManagetWithLookUpFieldsManager):
                         child_id='id')
 
                     with managed_progress(
-                            id=f'delete_pathes',
+                            id='delete_pathes',
                             qty=cnt - 1,
                             user=request.user,
                             message='Удаление путей размещения.',
@@ -213,17 +212,17 @@ class PathesManager(CommonManagetWithLookUpFieldsManager):
         except Pathes.DoesNotExist:
             return None
 
-    def get_drive(self, id):
-        try:
-            path = self.get(id=id)
-            if path.drive:
-                return path.drive
-            elif path.parent:
-                return self.get_drive(path.parent.id)
-            else:
-                return path.drive
-        except Pathes.DoesNotExist:
-            return None
+    # def get_drive(self, id):
+    #     try:
+    #         path = self.get(id=id)
+    #         if path.drive:
+    #             return path.drive
+    #         elif path.parent:
+    #             return self.get_drive(path.parent.id)
+    #         else:
+    #             return path.drive
+    #     except Pathes.DoesNotExist:
+    #         return None
 
 
 class Pathes(Hierarcy):
