@@ -42,7 +42,7 @@ class Spw_attrsQuerySet(Document_attributesQuerySet):
                 r = dict()
             attr_typee_id = record.attr_type.id
             setAttr(r, f'{record.attr_type.code}_ID', record.id)
-            setAttr(r, record.attr_type.code, record.value_str)
+            setAttr(r, record.attr_type.code, record.value_int if record.value_int is not None else record.value_str)
             setAttr(r, 'document_id', record.document.id)
             setAttr(r, 'section', record.section)
             setAttr(r, 'subsection', record.subsection)
@@ -50,7 +50,7 @@ class Spw_attrsQuerySet(Document_attributesQuerySet):
             max_position_in_raw_document = record.position_in_document
             setAttr(r, 'editing', True)
             setAttr(r, 'deliting', True)
-            if id == None:
+            if id is None:
                 id = str(record.id)
             else:
                 id += f'${record.id}'
@@ -82,12 +82,12 @@ class Spw_attrsManager(Document_attributes_viewManager):
 
         key = 'Spw_attrsManager.rec_document_attr'
         settings.LOCKS.acquire(key)
-        if attr_type_id == None:
-            if code != None and attr_type__code != None:
+        if attr_type_id is None:
+            if code is not None and attr_type__code is not None:
                 attr_type, _ = Document_attributesManager.get_or_create_attribute(attr_codes=code, value_str=attr_type__code)
                 attr_type_id = attr_type.id
 
-        if attr_type_id != None:
+        if attr_type_id is not None:
             value_int = StrToInt(value_str)
 
             document = Documents.objects.get(id=document_id)
@@ -110,7 +110,7 @@ class Spw_attrsManager(Document_attributes_viewManager):
             )
 
             position_in_document = None
-            if document_attr_cross_old != None:
+            if document_attr_cross_old is not None:
                 position_in_document = document_attr_cross_old.position_in_document
                 document_attr_cross_old.delete()
 
