@@ -1,15 +1,14 @@
 import logging
 
-from isc_common.fields.code_field import ColorField
 from isc_common.fields.related import ForeignKeyCascade, ForeignKeyProtect
-from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
+from isc_common.models.audit import AuditModel, AuditManager
 from isc_common.models.standard_colors import Standard_colors
-from kaf_pas.planing.models.operations import Operations
+from kaf_pas.planing.models.operations import Operations, BaseOperationQuerySet
 
 logger = logging.getLogger(__name__)
 
 
-class Operation_colorQuerySet(AuditQuerySet):
+class Operation_colorQuerySet(BaseOperationQuerySet):
     pass
 
 
@@ -45,4 +44,4 @@ class Operation_color(AuditModel):
 
     class Meta:
         verbose_name = 'Кросс таблица значений операции'
-        unique_together =(('operation','color'),)
+        unique_together = (('operation', 'color'))
