@@ -1,5 +1,7 @@
 import logging
 
+from bitfield import BitField
+
 from isc_common.fields.related import ForeignKeyCascade, ForeignKeyProtect
 from isc_common.models.audit import AuditModel, AuditManager
 from kaf_pas.planing.models.operations import Operations, BaseOperationQuerySet
@@ -13,6 +15,12 @@ class Operation_launchesQuerySet(BaseOperationQuerySet):
 
 class Operation_launchesManager(AuditManager):
 
+    @staticmethod
+    def props():
+        return BitField(flags=(
+            ('auxiliary', 'Прикрипленный запуск'),  # 0-1
+        ), default=0, db_index=True)
+
     @staticmethod
     def getRecord(record):
         res = {
@@ -29,6 +37,7 @@ class Operation_launchesManager(AuditManager):
 class Operation_launches(AuditModel):
     operation = ForeignKeyCascade(Operations, related_name='planing_operation_launch')
     launch = ForeignKeyProtect(Launches, related_name='planing_resource_launch')
+    props = Operation_launchesManager.props()
 
     objects = Operation_launchesManager()
 
