@@ -27,7 +27,7 @@ class Operation_resources_viewQuerySet(CommonQuerySet):
         launch_id = data.get('launch_id')
         if launch_id:
             launch = Launches.objects.get(id=launch_id)
-            if launch.parent != None:
+            if launch.parent is not None:
                 items = [operation_item_view.item for operation_item_view in Operation_item_view.objects.filter(opertype_id=settings.OPERS_TYPES_STACK.ROUTING_TASK.id, launch=launch).distinct()]
                 setAttr(request.json.get('data'), 'launch_id', launch.parent.id)
                 setAttr(request.json.get('data'), 'item', items)
