@@ -8,10 +8,10 @@ from django.db import transaction, connection
 from django.db.models import DecimalField, DateTimeField, TextField, BooleanField, BigIntegerField, PositiveIntegerField, SmallIntegerField
 from django.forms import model_to_dict
 
-from isc_common import setAttr, Stack, StackElementNotExist, Wrapper
+from isc_common import setAttr, Stack, StackElementNotExist
 from isc_common.auth.models.user import User
 from isc_common.bit import TurnBitOn
-from isc_common.common import blinkString, started, new, doing, red
+from isc_common.common import blinkString, started, new, doing, red, black
 from isc_common.common.functions import ExecuteStoredProc
 from isc_common.datetime import DateTimeToStr, DateToStr
 from isc_common.fields.code_field import CodeField, JSONFieldIVC
@@ -21,13 +21,13 @@ from isc_common.managers.common_manager import CommonManager
 from isc_common.models.audit import AuditModel, AuditQuerySet
 from isc_common.models.tree_audit import TreeAuditModelManager
 from isc_common.number import DecimalToStr, ToDecimal, Set, model_2_dict
-from isc_common.progress import managed_progreses, ProgressDroped, progress_deleted
+from isc_common.progress import managed_progreses, ProgressDroped, progress_deleted, managed_progress
 from isc_common.ws.webSocket import WebSocket
 from kaf_pas.ckk.models.item import Item
 from kaf_pas.planing.models.operation_types import Operation_types
 from kaf_pas.planing.models.operations import Operations
 from kaf_pas.planing.models.production_ext import Production_ext, Operation_executor_stack
-from kaf_pas.planing.models.production_order_values_ext import Production_orderWrapper
+from kaf_pas.planing.models.production_order_values_ext import Production_orderWrapper, Production_order_values_ext
 from kaf_pas.planing.models.rouning_ext import Routing_ext
 from kaf_pas.planing.views.production_order_opers import production_order_opers_opers_types
 from kaf_pas.production.models.launches import Launches
@@ -69,6 +69,7 @@ class ProductionOrderErrorStack(Stack):
 
 class Production_orderQuerySet(AuditQuerySet):
     production_ext = Production_ext()
+    production_order_values_ext = Production_order_values_ext()
 
     @staticmethod
     def get_user_locations(user):
@@ -232,6 +233,7 @@ class Production_orderQuerySet(AuditQuerySet):
         _res = []
 
         production_order_ids = Stack()
+        production_items = Stack()
 
         with transaction.atomic():
             operation_executor_stack = Operation_executor_stack()
@@ -251,22 +253,52 @@ class Production_orderQuerySet(AuditQuerySet):
                     where_clause=f'where location_ids && array [{location_id}::bigint] and launch_id={record.launch.id} and "isFolder" = {record.isFolder}',
                     where_clause1=f'where launch_id={record.launch.id}',
                 )
-                for parent_item_ref in parent_item_ref_query:
+                key = f'ungrouping_{location_id}'
+                settings.LOCKS.acquire(key)
 
-                    if not production_order_ids.exists(lambda x: x == parent_item_ref.id):
-                        if len(set(map(lambda x: x.user.id, Locations_users.objects.filter(location=Locations_view.objects.get(id=parent_item_ref.location_sector_ids[0]).workshop))).intersection([request.user.id])) == 0:
-                            production_order_ids.push(record.id)
-                            if not request.is_admin and not request.is_develop:
-                                continue
-                    else:
-                        continue
-
-                    _res.extend(self.production_ext.start(
-                        _data=self.delete_underscore_element(model_2_dict(parent_item_ref)),
-                        qty=qty,
+                with managed_progress(
+                        id=key,
+                        qty=len(list(parent_item_ref_query)),
                         user=request.user,
-                        operation_executor_stack=operation_executor_stack
-                    ))
+                        message='Внесение данных по запуску',
+                        title='Выполнено',
+                        props=TurnBitOn(0, 0)
+                ) as progress:
+
+                    def except_func():
+                        settings.LOCKS.release(key)
+
+                    progress.except_func = except_func
+                    for parent_item_ref in parent_item_ref_query:
+                        _qty = qty
+                        progress.setContentsLabel(blinkString(text=f'Внесение данных по запуску {parent_item_ref.item.item_name}, количество: {qty}', blink=False, color=black, bold=False))
+
+                        if not production_order_ids.exists(lambda x: x == parent_item_ref.id):
+                            if len(set(map(lambda x: x.user.id, Locations_users.objects.filter(location=Locations_view.objects.get(id=parent_item_ref.location_sector_ids[0]).workshop))).intersection([request.user.id])) == 0:
+                                production_order_ids.push(record.id)
+                                try:
+                                    _, parent_mul = production_items.find_one(lambda x: x[0] == parent_item_ref.parent_item.id)
+                                except StackElementNotExist:
+                                    parent_mul = 1
+
+                                _qty = qty * parent_mul * parent_item_ref.value1_sum[0]
+
+                                production_items.push((parent_item_ref.item.id, parent_mul * parent_item_ref.value1_sum[0]))
+                                if not request.is_admin and not request.is_develop:
+                                    continue
+                        else:
+                            continue
+
+                        _res.extend(self.production_ext.start(
+                            _data=self.delete_underscore_element(model_2_dict(parent_item_ref)),
+                            qty=_qty,
+                            user=request.user,
+                            operation_executor_stack=operation_executor_stack
+                        ))
+
+                        if progress.step() != 0:
+                            settings.LOCKS.release(key)
+                            raise ProgressDroped(progress_deleted)
 
             if len(_res) > 0:
                 ids = map(lambda x: x.get('id'), _res)
@@ -292,6 +324,7 @@ class Production_orderQuerySet(AuditQuerySet):
                         user=request.user
                     )
 
+            settings.LOCKS.release(key)
         return _res
 
     def check_selected_order_4_finish(self, request, production_order_ids, errors):
@@ -375,7 +408,6 @@ class Production_orderQuerySet(AuditQuerySet):
                         production_order_ids.push(item)
 
     def get_setFinishStatus(self, request):
-        from kaf_pas.planing.models.production_order_values_ext import Production_order_values_ext
 
         request = DSRequest(request=request)
         production_order_ids = ProductionOrderStack()
@@ -404,14 +436,17 @@ class Production_orderQuerySet(AuditQuerySet):
             raise Exception(f'<pre>{s}</pre>')
 
         with transaction.atomic():
-            production_order_values_ext = Production_order_values_ext()
-
-            res = production_order_values_ext.blockMakeAll1(
-                data=dict(records=production_order_ids.stack),
-                user=request.user
-            )
-
-            return res
+            try:
+                res = self.production_order_values_ext.blockMakeAll1(
+                    data=dict(records=production_order_ids.stack),
+                    qty=qty,
+                    user=request.user
+                )
+                production_order_ids.lock_release()
+                return res
+            except:
+                production_order_ids.lock_release()
+                return []
 
     def getLoocationUsers(self, request):
         from kaf_pas.ckk.models.locations_users import Locations_users
