@@ -2,12 +2,13 @@ import logging
 
 from django.conf import settings
 from django.db.models import ProtectedError, Sum
+from django.forms import model_to_dict
 
-from isc_common import Stack, Wrapper, delAttr
-from isc_common.common import new
+from isc_common import Stack, Wrapper, delAttr, setAttr, StackElementNotExist
+from isc_common.common import new, black, blinkString
 from isc_common.datetime import DateToStr
 from isc_common.json import StrToJson
-from isc_common.number import DecimalToStr, Set, ToDecimal, StrToNumber, model_2_dict
+from isc_common.number import DecimalToStr, Set, ToDecimal, model_2_dict
 from kaf_pas.planing.models.production_ext import Production_ext
 from kaf_pas.planing.models.production_order_values import Production_order_values
 from kaf_pas.planing.operation_typesStack import MADE_OPRS_MNS_TSK, MADE_OPRS_PLS_GRP_TSK
@@ -269,21 +270,6 @@ class Production_orderWrapper(Wrapper):
             self.parentRecord.childs = Production_order_opers.objects.filter(parent_id=self.parentRecord.this.id, deleted_at=None).order_by('production_operation_num')
             self.parentRecord.all_childs = Production_order_opers.objects.filter(parent_id=self.parentRecord.this.id).order_by('production_operation_num')
 
-        if isinstance(self.value, str):
-            self.value=ToDecimal(self.value)
-
-        if isinstance(self.value1_sum, str):
-            self.value1_sum=ToDecimal(self.value1_sum)
-
-        if isinstance(self.value1_sum_len, str):
-            self.value1_sum_len=ToDecimal(self.value1_sum_len)
-
-        if isinstance(self.value_made, str):
-            self.value_made=ToDecimal(self.value_made)
-
-        if isinstance(self.value_start, str):
-            self.value_start=ToDecimal(self.value_start)
-
         if isinstance(self.value_sum, str):
             self.value_sum=ToDecimal(self.value_sum)
 
@@ -327,20 +313,19 @@ class Production_order_values_ext:
 
         from django.conf import settings
         from django.db import transaction
-        from django.forms import model_to_dict
 
-        from isc_common import setAttr
         from isc_common.bit import TurnBitOn
-        from isc_common.common import new
         from isc_common.progress import managed_progress, ProgressDroped, progress_deleted
+
         from kaf_pas.ckk.models.ed_izm import Ed_izm
         from kaf_pas.ckk.models.locations_users import Locations_users
         from kaf_pas.ckk.models.locations_view import Locations_view
         from kaf_pas.planing.models.production_ext import Operation_executor_stack
         from kaf_pas.planing.models.production_order import Production_order
+        from kaf_pas.planing.models.production_order_per_launch import Production_order_per_launch
         from kaf_pas.planing.models.production_order import Production_orderManager
         from kaf_pas.planing.models.production_order_opers import Production_order_opers
-        from kaf_pas.planing.models.production_order_per_launch import Production_order_per_launch
+        from kaf_pas.planing.models.production_order_opers_per_launch import Production_order_opers_per_launch
 
         _res = []
 
@@ -371,8 +356,10 @@ class Production_order_values_ext:
 
                         if record.launch.parent is None:
                             model = Production_order
+                            model_opers = Production_order_opers
                         else:
                             model = Production_order_per_launch
+                            model_opers = Production_order_opers_per_launch
 
                         parent_item_ref_query = model.tree_objects.get_descendants(
                             id=record.item.id,
@@ -380,19 +367,21 @@ class Production_order_values_ext:
                             parent_id='parent_item_id',
                             where_clause=f'where location_ids && array [{location_id}::bigint] and launch_id={record.launch.id} and "isFolder" = {record.isFolder}',
                             where_clause1=f'where launch_id={record.launch.id}',
-                            order_by_clause='order by level'
+                            order_by_clause='order by level desc'
                         )
                         for parent_item_ref in parent_item_ref_query:
 
-                            if parent_item_ref.cnt_opers == 1 and not production_order_ids.exists(lambda x: x == parent_item_ref.id):
-                                if len(set(map(lambda x: x.user.id, Locations_users.objects.filter(location=Locations_view.objects.get(id=parent_item_ref.location_sector_ids[0]).workshop))).intersection([user.id])) == 0:
-                                    production_order_ids.push(record.id)
-                                    if not user.is_admin and not user.is_develop:
+                            if not production_order_ids.exists(lambda x: x == parent_item_ref.id):
+                                if user.is_admin or user.is_develop:
+                                    if Locations_view.objects.get(id=parent_item_ref.location_sector_ids[0]).workshop.id != location_id:
                                         continue
+                                elif len(set(map(lambda x: x.user.id, Locations_users.objects.filter(location=Locations_view.objects.get(id=parent_item_ref.location_sector_ids[0]).workshop))).intersection([user.id])) == 0:
+                                    production_order_ids.push(parent_item_ref.id)
+                                    continue
                             else:
                                 continue
 
-                            self.key_lock = f'''Production_order_values_{record.id}'''
+                            self.key_lock = f'''Production_order_values_{parent_item_ref.id}'''
                             settings.LOCKS.acquire(self.key_lock)
 
                             edizm = Ed_izm.objects.get(code='шт')
@@ -403,7 +392,7 @@ class Production_order_values_ext:
                             )
                             qty = parent_item_ref.value_sum
 
-                            if parent_item_ref.status.id == settings.OPERS_TYPES_STACK.PRODUCTION_TASK_STATUSES.get(new).id:
+                            if parent_item_ref.status.id == settings.OPERS_TYPES_STACK.PRODUCTION_TASK_STATUSES.get(new).id and parent_item_ref.cnt_opers == 1:
                                 self.production_ext.start(
                                     _data=_data,
                                     qty=qty,
@@ -414,8 +403,8 @@ class Production_order_values_ext:
 
                                 record_dict = model_2_dict(parent_item_ref)
 
-                                setAttr(record_dict, 'childs', [model_to_dict(production_order_opers) for production_order_opers in Production_order_opers.objects.filter(parent_id=record.id)])
-                                setAttr(record_dict, 'value', record.value_sum)
+                                setAttr(record_dict, 'childs', [model_to_dict(production_order_opers) for production_order_opers in model_opers.objects.filter(parent_id=parent_item_ref.id, launch=parent_item_ref.launch)])
+                                setAttr(record_dict, 'value', parent_item_ref.value_sum)
                                 setAttr(record_dict, 'edizm__name', edizm.name)
                                 setAttr(record_dict, 'edizm_id', edizm.id)
                                 setAttr(record_dict, 'value_start', qty)
@@ -459,23 +448,24 @@ class Production_order_values_ext:
         else:
             raise Exception('Не сделан выбор.')
 
-    def blockMakeAll1(self, data, user):
+    def blockMakeAll1(self, data, user, qty):
 
         from django.forms import model_to_dict
 
         from isc_common import setAttr
         from isc_common.bit import TurnBitOn
         from isc_common.progress import managed_progress, ProgressDroped, progress_deleted
-        from kaf_pas.planing.models.production_order import Production_order
-        from kaf_pas.planing.models.production_order_opers import Production_order_opers
         from kaf_pas.ckk.models.ed_izm import Ed_izm
         from kaf_pas.planing.models.production_order import Production_orderManager
+        from kaf_pas.planing.models.production_order_opers import Production_order_opers
+        from kaf_pas.planing.models.production_order_opers_per_launch import Production_order_opers_per_launch
 
         _res = []
 
         records = data.get('records')
         if isinstance(records, list):
 
+            production_items = Stack()
             with managed_progress(
                     id=f'blockMakeAll_{user.id}',
                     qty=len(records),
@@ -485,28 +475,43 @@ class Production_order_values_ext:
                     props=TurnBitOn(0, 0)
             ) as progress:
                 for record in records:
-                    production_order = Production_order.objects.get(id=record.get('id'))
+
+                    if record.launch.parent is None:
+                        model_opers = Production_order_opers
+                    else:
+                        model_opers = Production_order_opers_per_launch
+
+                    progress.setContentsLabel(blinkString(text=f'Внесение данных по выпуску: {record.item.item_name}', blink=False, color=black, bold=False))
+
+                    record_dict = model_2_dict(record)
 
                     edizm = Ed_izm.objects.get(code='шт')
                     _data = dict(
-                        id=production_order.id,
-                        launch_id=production_order.launch.id,
+                        id=record.id,
+                        launch_id=record.launch.id,
                         edizm_id=edizm.id
                     )
-                    qty = production_order.value_sum
 
-                    setAttr(record, 'childs', [model_to_dict(production_order_opers) for production_order_opers in Production_order_opers.objects.filter(parent_id=production_order.id)])
-                    setAttr(record, 'value', production_order.value_sum)
-                    setAttr(record, 'edizm__name', edizm.name)
-                    setAttr(record, 'edizm_id', edizm.id)
-                    setAttr(record, 'value_start', qty)
+                    try:
+                        _, parent_mul = production_items.find_one(lambda x: x[0] == record.parent_item.id)
+                    except StackElementNotExist:
+                        parent_mul = 1
 
-                    delAttr(record, 'launch_id')
-                    delAttr(record, 'launch__code')
-                    delAttr(record, 'launch__name')
+                    _qty = qty * parent_mul * record.value1_sum[0]
+
+                    production_items.push((record.item.id, parent_mul * record.value1_sum[0]))
+
+                    setAttr(record_dict, 'childs', [model_to_dict(production_order_opers) for production_order_opers in model_opers.objects.filter(parent_id=record.id, launch=record.launch)])
+                    setAttr(record_dict, 'value', _qty)
+                    setAttr(record_dict, 'edizm__name', edizm.name)
+                    setAttr(record_dict, 'edizm_id', edizm.id)
+
+                    delAttr(record_dict, 'launch_id')
+                    delAttr(record_dict, 'launch__code')
+                    delAttr(record_dict, 'launch__name')
 
                     res, _ = self.makeAll(
-                        data=record,
+                        data=record_dict,
                         user=user,
                         lock=False
                     )
