@@ -210,7 +210,7 @@ class Launch_operation_resources(AuditModel):
     launch_operationitem = OneToOneField(Launch_operations_item, on_delete=CASCADE)
     location = ForeignKeyProtect(Locations, related_name='Launch_operation_resources_location')
     location_fin = ForeignKeyProtect(Locations, related_name='Launch_operation_resources_location_fin', null=True, blank=True)
-    operation_resources = ForeignKeySetNull(Operation_resources, null=True, blank=True)
+    operation_resources = ForeignKeyProtect(Operation_resources)
     resource = ForeignKeyProtect(Resource, related_name='Launch_operation_resources_resource')
     resource_fin = ForeignKeyProtect(Resource, related_name='Launch_operation_resources_resource_fin', null=True, blank=True)
 
