@@ -5,7 +5,7 @@ from django.db import transaction
 from isc_common import setAttr, delAttr
 from isc_common.fields.related import ForeignKeyCascade, ForeignKeyProtect
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
-from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
+from isc_common.models.audit import AuditModel
 from kaf_pas.ckk.models.attr_type import Attr_type
 from kaf_pas.production.models.operations import Operations
 
