@@ -22,13 +22,30 @@ logger = logging.getLogger(__name__)
 
 
 class Operations_itemQuerySet(CommonManagetWithLookUpFieldsQuerySet):
+    def get_range_rows1(self, request, function=None, distinct_field_names=None, remove_fields=None):
+        request = DSRequest(request=request)
+        request.set_sort_by('num')
+
+        self.alive_only = request.alive_only
+        self.enabledAll = request.enabledAll
+        res = self.get_range_rows(
+            start=request.startRow,
+            end=request.endRow,
+            function=function,
+            distinct_field_names=distinct_field_names,
+            json=request.json,
+            criteria=request.get_criteria(),
+            user=request.user
+        )
+        return res
+
     def create(self, **kwargs):
-        if kwargs.get('props') == None:
+        if kwargs.get('props') is None:
             setAttr(kwargs, 'props', Operations_item.props.created)
         return super().create(**kwargs)
 
     def update(self, **kwargs):
-        if kwargs.get('props') == None:
+        if kwargs.get('props') is None:
             setAttr(kwargs, 'props', Operations_item.props.updated)
         return super().update(**kwargs)
 
@@ -179,26 +196,27 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
             raise Exception('operations_item must be list')
 
         def check_location(operation_resources, cont):
-            if operation_resources.location == None:
-                if errors_set != None:
+            if operation_resources.location is None:
+                if errors_set is not None:
                     operation_resources.operationitem.delete()
                     errors_set.add(f'К операции: {operation_resources.operationitem.operation.full_name} не привязано местоположение. И была удалана.')
                     return False
                 else:
                     raise Exception(f'Товарная позиция: {operation_item.item.item_name}, операция: {operation_resources.operation.full_name} не привязано местоположение.')
             elif operation_resources.location.is_workshop:
-                if errors_set != None:
+                if errors_set is not None:
                     def_operation_resources = Operation_def_resources.objects.get(operation=operation_resources.operationitem.operation)
-                    if def_operation_resources.location.is_workshop:
-                        errors_set.add(f'Операция: {operation_resources.operationitem.operation.full_name} привязана на уровне цеха.')
-                        return False
-                    else:
-                        operation_resources.location = def_operation_resources.location
-                        operation_resources.location_fin = def_operation_resources.location_fin
-                        operation_resources.save()
+                    # Убрал 27/10/2020 Не дает транспортировать на ПДО т.к. это цех
+                    # if def_operation_resources.location.is_workshop:
+                    #     errors_set.add(f'Операция: {operation_resources.operationitem.operation.full_name} привязана на уровне цеха.')
+                    #     return False
+                    # else:
+                    operation_resources.location = def_operation_resources.location
+                    operation_resources.location_fin = def_operation_resources.location_fin
+                    operation_resources.save()
 
-                else:
-                    raise Exception(f'Товарная позиция: {operation_item.item.item_name}, операция: {operation_resources.operationitem.operation.full_name} привязана на уровне цеха.')
+                # else:
+                #     raise Exception(f'Товарная позиция: {operation_item.item.item_name}, операция: {operation_resources.operationitem.operation.full_name} привязана на уровне цеха.')
 
             return cont
 
@@ -228,7 +246,7 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
                         cont = check_location(operation_resources=operation_resources_before, cont=cont)
 
                     except Operation_def_resources.DoesNotExist:
-                        if errors_set != None:
+                        if errors_set is not None:
                             operation_before.delete()
                             errors_set.add(f'К операции: {operation_before.operation.full_name} не привязано местоположение. И была удалана.')
                             cont = False
@@ -244,7 +262,7 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
                         cont = check_location(operation_resources=operation_resources_after, cont=cont)
 
                     except Operation_def_resources.DoesNotExist:
-                        if errors_set != None:
+                        if errors_set is not None:
                             operation_after.delete()
                             errors_set.add(f'К операции: {operation_after.operation.full_name} не привязано местоположение. И была удалана.')
                             cont = False
@@ -327,7 +345,7 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
         data = request.get_data()
         old_data = request.get_oldValues()
 
-        if data.get('record') != None:
+        if data.get('record') is not None:
             data.update(data.get('record'))
             delAttr(data, 'record')
 
@@ -338,11 +356,11 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
         data = OI_Wrapper(**data)
         data_old = OI_Wrapper(**old_data)
 
-        if data.dropIndex != None:
+        if data.dropIndex is not None:
             data.num = data.dropIndex + 1
 
-        if data.num == None:
-            if data.dropIndex != None:
+        if data.num is None:
+            if data.dropIndex is not None:
                 data.num = data.dropIndex + 1
 
         key = f'OperationsManager.make_routing_{data.id}'
@@ -354,29 +372,32 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
                 # Выравниваем нумерацию ели изменен порядок следования операций
                 operation_item = Operations_item.objects.get(id=data.id)
                 operations_item = list(Operations_item.objects.filter(item=operation_item.item, deleted_at=None).order_by('num'))
-
-                if data.num != data_old.num:
-
-                    operations_item = list(Operations_item.objects.filter(item=operation_item.item, deleted_at=None).order_by('num').exclude(id=operation_item.id))
-
-                    num = 1
-                    for oi in operations_item:
-                        oi.num = num
-                        oi.save()
-                        num += 1
-
-                    if data.num >= len(operations_item):
-                        operations_item.append(operation_item)
-                    else:
-                        operations_item.insert(data.num - 1, operation_item)
-
-                    num = 1
-                    for oi in operations_item:
-                        oi.num = num
-                        oi.save()
-                        num += 1
+                #
+                # if data.num != data_old.num:
+                #
+                #     operations_item = list(Operations_item.objects.filter(item=operation_item.item, deleted_at=None).order_by('num').exclude(id=operation_item.id))
+                #
+                #     num = 1
+                #     for oi in operations_item:
+                #         oi.num = num
+                #         oi.save()
+                #         num += 1
+                #
+                #     if data.num >= len(operations_item):
+                #         operations_item.append(operation_item)
+                #     else:
+                #         operations_item.insert(data.num - 1, operation_item)
+                #
+                #     num = 1
+                #     for oi in operations_item:
+                #         oi.num = num
+                #         oi.save()
+                #         num += 1
 
                 # Если это транспртировочная операция, то проверяем начальную и конечные точки местарасположения
+                if operation_item.num is None and _data.get('num') is not None:
+                    operation_item.num = _data.get('num')
+
                 Operations_itemManager.check_tansport_operations(
                     operations_item=operations_item,
                     operation_item=operation_item
@@ -397,10 +418,10 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
                             break
                         else:
 
-                            data.num = operation_item.num
+                            # data.num = operation_item.num
                             data1 = dict()
                             for k1, v1 in data.dict.items():
-                                if k1.find('__') == -1:
+                                if k1.find('_') == -1:
                                     setAttr(data1, k1, v1)
 
                             delAttr(data1, 'id')
