@@ -1,8 +1,6 @@
-from django.utils.translation import ugettext_lazy as _
-
 import logging
 
-from isc_common.models.base_ref import BaseRef, BaseRefManager, BaseRefQuerySet, BaseRefHierarcy
+from isc_common.models.base_ref import BaseRefManager, BaseRefQuerySet, BaseRefHierarcy
 
 logger = logging.getLogger(__name__)
 
