@@ -195,10 +195,10 @@ class Ready_2_launchManager(AuditManager):
             'check_operation': record.props.check_operation,
             'check_colvo': record.props.check_colvo,
             'item_id': record.item.id,
-            'item__STMP_1_id': record.item.STMP_1.id if record.item.STMP_1 != None else None,
-            'item__STMP_1__value_str': record.item.STMP_1.value_str if record.item.STMP_1 != None else None,
-            'item__STMP_2_id': record.item.STMP_2.id if record.item.STMP_2 != None else None,
-            'item__STMP_2__value_str': record.item.STMP_2.value_str if record.item.STMP_2 != None else None,
+            'item__STMP_1_id': record.item.STMP_1.id if record.item.STMP_1 is not None else None,
+            'item__STMP_1__value_str': record.item.STMP_1.value_str if record.item.STMP_1 is not None else None,
+            'item__STMP_2_id': record.item.STMP_2.id if record.item.STMP_2 is not None else None,
+            'item__STMP_2__value_str': record.item.STMP_2.value_str if record.item.STMP_2 is not None else None,
             'notes': record.notes,
             'editing': record.editing,
             'deliting': record.deliting,
