@@ -3,7 +3,7 @@ import logging
 from django.db import connection
 
 from isc_common import Stack
-from isc_common.common import orange, blinkString, red, black
+from isc_common.common import blinkString, red, black
 
 logger = logging.getLogger(__name__)
 
@@ -60,7 +60,7 @@ class Item_refs_Stack(Stack):
                                                     where launch_id = %s order by level desc''', [id, launch_id]):
                 self.push(item_ref)
 
-    def add_childs(self, id):
+    def add_childs(self, id, alive_only=True):
         if isinstance(id, int):
             id = tuple(id)
 
@@ -73,10 +73,14 @@ class Item_refs_Stack(Stack):
         if len(id) == 0:
             id = tuple([0])
 
+        alive_only_str = ''
+        if alive_only is True:
+            alive_only_str = f'where deleted_at is null'
+
         with connection.cursor() as cursor:
-            cursor.execute('''select *
+            sql_str = f'''select *
                             from (WITH RECURSIVE r AS (
-                                SELECT id, child_id, parent_id, props, 1 AS level
+                                SELECT id, child_id, parent_id, props, deleted_at, 1 AS level
                                 FROM ckk_item_refs
                                 WHERE child_id IN %s
                                 union all
@@ -84,13 +88,17 @@ class Item_refs_Stack(Stack):
                                         ckk_item_refs.child_id, 
                                         ckk_item_refs.parent_id, 
                                         ckk_item_refs.props, 
+                                        ckk_item_refs.deleted_at, 
                                         r.level + 1 AS level
                                 FROM ckk_item_refs
                                          JOIN r
-                                              ON ckk_item_refs.parent_id = r.child_id)           
+                                              ON ckk_item_refs.parent_id = r.child_id)
                                   select distinct *
                                   from r
-                                  order by level) as s''', [id])
+                                  {alive_only_str}  
+                                  order by level) as s'''
+
+            cursor.execute(sql_str, [id])
             rows = cursor.fetchall()
             return rows
 
