@@ -26,7 +26,7 @@ class Operation_Stack:
             ))
 
             def rec(location):
-                if location != None:
+                if location is not None:
                     return Resource.objects.get_or_create(
                         location=location,
                         code='none',
