@@ -1,6 +1,6 @@
 from django.urls import path
 
-from kaf_pas.production.views import launch_operations_item, operations_item
+from kaf_pas.production.views import launch_operations_item
 
 urlpatterns = [
 
